﻿namespace WindowsFormsApplication1
{
    #region Usings
    using System;
    using System.Collections.Generic;
    using System.ComponentModel;
    using System.Drawing;
    using System.Windows.Forms;
    #endregion

    //Author: H.Esmaeily
    [Description("فراهم کننده داده های بر خط")]
    [ProvideProperty("SupportChangerColor", typeof(TextBox))]
    public partial class TextBoxColorProvider : Component, IExtenderProvider
    {
        #region Fields
        private Color enterColor = Color.Pink;
        private Color leaveColoe = Color.White;

        private Dictionary<TextBox, bool> textboxTable = new Dictionary<TextBox, bool>();
        #endregion

        #region Ctor
        public TextBoxColorProvider()
        {
            InitializeComponent();
        }

        public TextBoxColorProvider(IContainer container)
        {
            container.Add(this);

            InitializeComponent();
        }

        #endregion

        #region props

        [Category("Appearance")]
        [Description("رنگ جعبه متن هنگام قرار گیری فوکوس")]
        public Color EnterColor
        {
            get { return enterColor; }
            set { enterColor = value; }
        }

        [Category("Appearance")]
        [Description("رنگ جعبه متن هنگام از دست دادن فوکوس")]
        public Color LeaveColor
        {
            get { return leaveColoe; }
            set { leaveColoe = value; }
        }
        #endregion

        #region Method(s)
        [Description("Set Support Changer Color")]
        public void SetSupportChangerColor(TextBox textbox, bool value)
        {
            if (!textboxTable.ContainsKey(textbox))
                textboxTable.Add(textbox, value);
            else
                textboxTable[textbox] = value;

            if (value)
            {
                textbox.Enter += this.textbox_Enter;
                textbox.Leave += this.textbox_Leave;
            }
            else
            {
                textbox.Enter -= this.textbox_Enter;
                textbox.Leave -= this.textbox_Leave;
            }
        }

        

        [Description("Get Support Changer Color")]
        [DefaultValue(false)]
        public bool GetSupportChangerColor(TextBox textbox)
        {
            if (!textboxTable.ContainsKey(textbox))
                return false;
            return textboxTable[textbox];
        }





        #endregion

        #region Method of events
        private void textbox_Enter(object sender, EventArgs e)
        {
            (sender as TextBox).BackColor = EnterColor;
        }

        private void textbox_Leave(object sender, EventArgs e)
        {
            (sender as TextBox).BackColor = LeaveColor;
        }
        #endregion

        #region IExtenderProvider Members

        public bool CanExtend(object extendee)
        {
            return extendee is TextBox;
        }

        #endregion

    }//end class
}//end namespace
